@@ -246,29 +246,29 @@ var searchData=
   ['arraybase_3c_20double_2c_20dummycriticalsection_20_3e_243',['ArrayBase&lt; double, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20dragimagecomponent_20_2a_2c_20dummycriticalsection_20_3e_244',['ArrayBase&lt; DragImageComponent *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20drawablebutton_20_2a_2c_20dummycriticalsection_20_3e_245',['ArrayBase&lt; DrawableButton *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20dsp_3a_3afirstordertptfilter_3c_20sampletype_20_3e_20_2a_2c_20dummycriticalsection_20_3e_246',['ArrayBase&lt; dsp::FirstOrderTPTFilter&lt; SampleType &gt; *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20elementtype_2c_20dummycriticalsection_20_3e_247',['ArrayBase&lt; ElementType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20file_2c_20dummycriticalsection_20_3e_248',['ArrayBase&lt; File, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20filebrowserlistener_20_2a_2c_20dummycriticalsection_20_3e_249',['ArrayBase&lt; FileBrowserListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20filenamecomponentlistener_20_2a_2c_20dummycriticalsection_20_3e_250',['ArrayBase&lt; FilenameComponentListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20flexitem_2c_20dummycriticalsection_20_3e_251',['ArrayBase&lt; FlexItem, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20float_2c_20dummycriticalsection_20_3e_252',['ArrayBase&lt; float, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20floatingtype_2c_20dummycriticalsection_20_3e_253',['ArrayBase&lt; FloatingType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20floattype_2c_20dummycriticalsection_20_3e_254',['ArrayBase&lt; FloatType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20focuschangelistener_20_2a_2c_20dummycriticalsection_20_3e_255',['ArrayBase&lt; FocusChangeListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20glyphinfo_20_2a_2c_20dummycriticalsection_20_3e_256',['ArrayBase&lt; GlyphInfo *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20grid_3a_3atrackinfo_2c_20dummycriticalsection_20_3e_257',['ArrayBase&lt; Grid::TrackInfo, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20griditem_2c_20dummycriticalsection_20_3e_258',['ArrayBase&lt; GridItem, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20hashentry_20_2a_2c_20dummycriticalsection_20_3e_259',['ArrayBase&lt; HashEntry *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20iircoefficients_20_2a_2c_20dummycriticalsection_20_3e_260',['ArrayBase&lt; IIRCoefficients *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20iirfilter_20_2a_2c_20dummycriticalsection_20_3e_261',['ArrayBase&lt; IIRFilter *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20imagepixeldata_3a_3alistener_20_2a_2c_20dummycriticalsection_20_3e_262',['ArrayBase&lt; ImagePixelData::Listener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20inapppurchases_3a_3adownload_20_2a_2c_20dummycriticalsection_20_3e_263',['ArrayBase&lt; InAppPurchases::Download *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20inapppurchases_3a_3alistener_20_2a_2c_20dummycriticalsection_20_3e_264',['ArrayBase&lt; InAppPurchases::Listener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20int_2c_20dummycriticalsection_20_3e_265',['ArrayBase&lt; int, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20item_20_2a_2c_20dummycriticalsection_20_3e_266',['ArrayBase&lt; Item *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20item_2c_20dummycriticalsection_20_3e_267',['ArrayBase&lt; Item, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraybase_3c_20itemlayoutproperties_20_2a_2c_20dummycriticalsection_20_3e_268',['ArrayBase&lt; ItemLayoutProperties *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20elementtype_2c_20dummycriticalsection_20_3e_246',['ArrayBase&lt; ElementType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20file_2c_20dummycriticalsection_20_3e_247',['ArrayBase&lt; File, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20filebrowserlistener_20_2a_2c_20dummycriticalsection_20_3e_248',['ArrayBase&lt; FileBrowserListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20filenamecomponentlistener_20_2a_2c_20dummycriticalsection_20_3e_249',['ArrayBase&lt; FilenameComponentListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20flexitem_2c_20dummycriticalsection_20_3e_250',['ArrayBase&lt; FlexItem, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20float_2c_20dummycriticalsection_20_3e_251',['ArrayBase&lt; float, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20floatingtype_2c_20dummycriticalsection_20_3e_252',['ArrayBase&lt; FloatingType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20floattype_2c_20dummycriticalsection_20_3e_253',['ArrayBase&lt; FloatType, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20focuschangelistener_20_2a_2c_20dummycriticalsection_20_3e_254',['ArrayBase&lt; FocusChangeListener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20glyphinfo_20_2a_2c_20dummycriticalsection_20_3e_255',['ArrayBase&lt; GlyphInfo *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20grid_3a_3atrackinfo_2c_20dummycriticalsection_20_3e_256',['ArrayBase&lt; Grid::TrackInfo, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20griditem_2c_20dummycriticalsection_20_3e_257',['ArrayBase&lt; GridItem, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20hashentry_20_2a_2c_20dummycriticalsection_20_3e_258',['ArrayBase&lt; HashEntry *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20iircoefficients_20_2a_2c_20dummycriticalsection_20_3e_259',['ArrayBase&lt; IIRCoefficients *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20iirfilter_20_2a_2c_20dummycriticalsection_20_3e_260',['ArrayBase&lt; IIRFilter *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20imagepixeldata_3a_3alistener_20_2a_2c_20dummycriticalsection_20_3e_261',['ArrayBase&lt; ImagePixelData::Listener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20inapppurchases_3a_3adownload_20_2a_2c_20dummycriticalsection_20_3e_262',['ArrayBase&lt; InAppPurchases::Download *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20inapppurchases_3a_3alistener_20_2a_2c_20dummycriticalsection_20_3e_263',['ArrayBase&lt; InAppPurchases::Listener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20int_2c_20dummycriticalsection_20_3e_264',['ArrayBase&lt; int, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20item_20_2a_2c_20dummycriticalsection_20_3e_265',['ArrayBase&lt; Item *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20item_2c_20dummycriticalsection_20_3e_266',['ArrayBase&lt; Item, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20itemlayoutproperties_20_2a_2c_20dummycriticalsection_20_3e_267',['ArrayBase&lt; ItemLayoutProperties *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
+  ['arraybase_3c_20juce_3a_3adsp_3a_3afirstordertptfilter_3c_20sampletype_20_3e_20_2a_2c_20dummycriticalsection_20_3e_268',['ArrayBase&lt; juce::dsp::FirstOrderTPTFilter&lt; SampleType &gt; *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20keypress_2c_20dummycriticalsection_20_3e_269',['ArrayBase&lt; KeyPress, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20keypresstime_20_2a_2c_20dummycriticalsection_20_3e_270',['ArrayBase&lt; KeyPressTime *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20knownpluginlist_3a_3aplugintree_20_2a_2c_20dummycriticalsection_20_3e_271',['ArrayBase&lt; KnownPluginList::PluginTree *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
@@ -351,7 +351,7 @@ var searchData=
   ['arraybase_3c_20valuetree_3a_3alistener_20_2a_2c_20dummycriticalsection_20_3e_348',['ArrayBase&lt; ValueTree::Listener *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20weakreference_3c_20component_20_3e_2c_20dummycriticalsection_20_3e_349',['ArrayBase&lt; WeakReference&lt; Component &gt;, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
   ['arraybase_3c_20zipentryholder_20_2a_2c_20dummycriticalsection_20_3e_350',['ArrayBase&lt; ZipEntryHolder *, DummyCriticalSection &gt;',['../classArrayBase.html',1,'']]],
-  ['arraycoefficients_351',['ArrayCoefficients',['../structdsp_1_1IIR_1_1ArrayCoefficients.html',1,'dsp::IIR']]],
+  ['arraycoefficients_351',['ArrayCoefficients',['../structjuce_1_1dsp_1_1IIR_1_1ArrayCoefficients.html',1,'juce::dsp::IIR']]],
   ['arrowbutton_352',['ArrowButton',['../classArrowButton.html',1,'']]],
   ['asyncupdater_353',['AsyncUpdater',['../classAsyncUpdater.html',1,'']]],
   ['atomic_354',['Atomic',['../structAtomic.html',1,'']]],
@@ -359,12 +359,12 @@ var searchData=
   ['atomic_3c_20int_20_3e_356',['Atomic&lt; int &gt;',['../structAtomic.html',1,'']]],
   ['atomic_3c_20objectholder_20_2a_20_3e_357',['Atomic&lt; ObjectHolder * &gt;',['../structAtomic.html',1,'']]],
   ['atomic_3c_20thread_3a_3athreadid_20_3e_358',['Atomic&lt; Thread::ThreadID &gt;',['../structAtomic.html',1,'']]],
-  ['attribute_359',['Attribute',['../classAttributedString_1_1Attribute.html',1,'AttributedString::Attribute'],['../structOpenGLShaderProgram_1_1Attribute.html',1,'OpenGLShaderProgram::Attribute']]],
+  ['attribute_359',['attribute',['../classAttributedString_1_1Attribute.html',1,'AttributedString::Attribute'],['../structOpenGLShaderProgram_1_1Attribute.html',1,'OpenGLShaderProgram::Attribute']]],
   ['attributedstring_360',['AttributedString',['../classAttributedString.html',1,'']]],
   ['audioappcomponent_361',['AudioAppComponent',['../classAudioAppComponent.html',1,'']]],
-  ['audioblock_362',['AudioBlock',['../classdsp_1_1AudioBlock.html',1,'dsp']]],
-  ['audioblock_3c_20const_20sampletype_20_3e_363',['AudioBlock&lt; const SampleType &gt;',['../classdsp_1_1AudioBlock.html',1,'dsp']]],
-  ['audioblock_3c_20float_20_3e_364',['AudioBlock&lt; float &gt;',['../classdsp_1_1AudioBlock.html',1,'dsp']]],
+  ['audioblock_362',['AudioBlock',['../classjuce_1_1dsp_1_1AudioBlock.html',1,'juce::dsp']]],
+  ['audioblock_3c_20const_20sampletype_20_3e_363',['AudioBlock&lt; const SampleType &gt;',['../classjuce_1_1dsp_1_1AudioBlock.html',1,'juce::dsp']]],
+  ['audioblock_3c_20float_20_3e_364',['AudioBlock&lt; float &gt;',['../classjuce_1_1dsp_1_1AudioBlock.html',1,'juce::dsp']]],
   ['audiobuffer_365',['AudioBuffer',['../classAudioBuffer.html',1,'']]],
   ['audiobuffer_3c_20double_20_3e_366',['AudioBuffer&lt; double &gt;',['../classAudioBuffer.html',1,'']]],
   ['audiobuffer_3c_20float_20_3e_367',['AudioBuffer&lt; float &gt;',['../classAudioBuffer.html',1,'']]],
@@ -387,45 +387,45 @@ var searchData=
   ['audioiodevicecallback_384',['AudioIODeviceCallback',['../classAudioIODeviceCallback.html',1,'']]],
   ['audioiodevicecallbackcontext_385',['AudioIODeviceCallbackContext',['../structAudioIODeviceCallbackContext.html',1,'']]],
   ['audioiodevicetype_386',['AudioIODeviceType',['../classAudioIODeviceType.html',1,'']]],
-  ['audiomodification_387',['AudioModification',['../classARAHostModel_1_1AudioModification.html',1,'ARAHostModel']]],
-  ['audioparameterbool_388',['AudioParameterBool',['../classAudioParameterBool.html',1,'']]],
-  ['audioparameterboolattributes_389',['AudioParameterBoolAttributes',['../classAudioParameterBoolAttributes.html',1,'']]],
-  ['audioparameterchoice_390',['AudioParameterChoice',['../classAudioParameterChoice.html',1,'']]],
-  ['audioparameterchoiceattributes_391',['AudioParameterChoiceAttributes',['../classAudioParameterChoiceAttributes.html',1,'']]],
-  ['audioparameterfloat_392',['AudioParameterFloat',['../classAudioParameterFloat.html',1,'']]],
-  ['audioparameterfloatattributes_393',['AudioParameterFloatAttributes',['../classAudioParameterFloatAttributes.html',1,'']]],
-  ['audioparameterint_394',['AudioParameterInt',['../classAudioParameterInt.html',1,'']]],
-  ['audioparameterintattributes_395',['AudioParameterIntAttributes',['../classAudioParameterIntAttributes.html',1,'']]],
-  ['audioplayhead_396',['AudioPlayHead',['../classAudioPlayHead.html',1,'']]],
-  ['audiopluginformat_397',['AudioPluginFormat',['../classAudioPluginFormat.html',1,'']]],
-  ['audiopluginformatmanager_398',['AudioPluginFormatManager',['../classAudioPluginFormatManager.html',1,'']]],
-  ['audioplugininstance_399',['AudioPluginInstance',['../classAudioPluginInstance.html',1,'']]],
-  ['audioprocessloadmeasurer_400',['AudioProcessLoadMeasurer',['../classAudioProcessLoadMeasurer.html',1,'']]],
-  ['audioprocessor_401',['AudioProcessor',['../classAudioProcessor.html',1,'']]],
-  ['audioprocessoraraextension_402',['AudioProcessorARAExtension',['../classAudioProcessorARAExtension.html',1,'']]],
-  ['audioprocessoreditor_403',['AudioProcessorEditor',['../classAudioProcessorEditor.html',1,'']]],
-  ['audioprocessoreditoraraextension_404',['AudioProcessorEditorARAExtension',['../classAudioProcessorEditorARAExtension.html',1,'']]],
-  ['audioprocessoreditorhostcontext_405',['AudioProcessorEditorHostContext',['../structAudioProcessorEditorHostContext.html',1,'']]],
-  ['audioprocessorgraph_406',['AudioProcessorGraph',['../classAudioProcessorGraph.html',1,'']]],
-  ['audioprocessorlistener_407',['AudioProcessorListener',['../classAudioProcessorListener.html',1,'']]],
-  ['audioprocessorparameter_408',['AudioProcessorParameter',['../classAudioProcessorParameter.html',1,'']]],
-  ['audioprocessorparametergroup_409',['AudioProcessorParameterGroup',['../classAudioProcessorParameterGroup.html',1,'']]],
-  ['audioprocessorparameternode_410',['AudioProcessorParameterNode',['../classAudioProcessorParameterGroup_1_1AudioProcessorParameterNode.html',1,'AudioProcessorParameterGroup']]],
-  ['audioprocessorparameterwithid_411',['AudioProcessorParameterWithID',['../classAudioProcessorParameterWithID.html',1,'']]],
-  ['audioprocessorparameterwithidattributes_412',['AudioProcessorParameterWithIDAttributes',['../classAudioProcessorParameterWithIDAttributes.html',1,'']]],
-  ['audioprocessorplayer_413',['AudioProcessorPlayer',['../classAudioProcessorPlayer.html',1,'']]],
-  ['audioprocessorvaluetreestate_414',['AudioProcessorValueTreeState',['../classAudioProcessorValueTreeState.html',1,'']]],
-  ['audioprocessorvaluetreestateparameterattributes_415',['AudioProcessorValueTreeStateParameterAttributes',['../classAudioProcessorValueTreeStateParameterAttributes.html',1,'']]],
-  ['audiosource_416',['AudioSource',['../classARAHostModel_1_1AudioSource.html',1,'ARAHostModel::AudioSource'],['../classAudioSource.html',1,'AudioSource']]],
-  ['audiosourcechannelinfo_417',['AudioSourceChannelInfo',['../structAudioSourceChannelInfo.html',1,'']]],
-  ['audiosourceplayer_418',['AudioSourcePlayer',['../classAudioSourcePlayer.html',1,'']]],
-  ['audiosubsectionreader_419',['AudioSubsectionReader',['../classAudioSubsectionReader.html',1,'']]],
-  ['audiothumbnail_420',['AudioThumbnail',['../classAudioThumbnail.html',1,'']]],
-  ['audiothumbnailbase_421',['AudioThumbnailBase',['../classAudioThumbnailBase.html',1,'']]],
-  ['audiothumbnailcache_422',['AudioThumbnailCache',['../classAudioThumbnailCache.html',1,'']]],
-  ['audiotransportsource_423',['AudioTransportSource',['../classAudioTransportSource.html',1,'']]],
-  ['audiounitclient_424',['AudioUnitClient',['../structExtensionsVisitor_1_1AudioUnitClient.html',1,'ExtensionsVisitor']]],
-  ['audiounitpluginformat_425',['AudioUnitPluginFormat',['../classAudioUnitPluginFormat.html',1,'']]],
-  ['audiovisualisercomponent_426',['AudioVisualiserComponent',['../classAudioVisualiserComponent.html',1,'']]],
+  ['audioparameterbool_387',['AudioParameterBool',['../classAudioParameterBool.html',1,'']]],
+  ['audioparameterboolattributes_388',['AudioParameterBoolAttributes',['../classAudioParameterBoolAttributes.html',1,'']]],
+  ['audioparameterchoice_389',['AudioParameterChoice',['../classAudioParameterChoice.html',1,'']]],
+  ['audioparameterchoiceattributes_390',['AudioParameterChoiceAttributes',['../classAudioParameterChoiceAttributes.html',1,'']]],
+  ['audioparameterfloat_391',['AudioParameterFloat',['../classAudioParameterFloat.html',1,'']]],
+  ['audioparameterfloatattributes_392',['AudioParameterFloatAttributes',['../classAudioParameterFloatAttributes.html',1,'']]],
+  ['audioparameterint_393',['AudioParameterInt',['../classAudioParameterInt.html',1,'']]],
+  ['audioparameterintattributes_394',['AudioParameterIntAttributes',['../classAudioParameterIntAttributes.html',1,'']]],
+  ['audioplayhead_395',['AudioPlayHead',['../classAudioPlayHead.html',1,'']]],
+  ['audiopluginformat_396',['AudioPluginFormat',['../classAudioPluginFormat.html',1,'']]],
+  ['audiopluginformatmanager_397',['AudioPluginFormatManager',['../classAudioPluginFormatManager.html',1,'']]],
+  ['audioplugininstance_398',['AudioPluginInstance',['../classAudioPluginInstance.html',1,'']]],
+  ['audioprocessloadmeasurer_399',['AudioProcessLoadMeasurer',['../classAudioProcessLoadMeasurer.html',1,'']]],
+  ['audioprocessor_400',['AudioProcessor',['../classAudioProcessor.html',1,'']]],
+  ['audioprocessoraraextension_401',['AudioProcessorARAExtension',['../classAudioProcessorARAExtension.html',1,'']]],
+  ['audioprocessoreditor_402',['AudioProcessorEditor',['../classAudioProcessorEditor.html',1,'']]],
+  ['audioprocessoreditoraraextension_403',['AudioProcessorEditorARAExtension',['../classAudioProcessorEditorARAExtension.html',1,'']]],
+  ['audioprocessoreditorhostcontext_404',['AudioProcessorEditorHostContext',['../structAudioProcessorEditorHostContext.html',1,'']]],
+  ['audioprocessorgraph_405',['AudioProcessorGraph',['../classAudioProcessorGraph.html',1,'']]],
+  ['audioprocessorlistener_406',['AudioProcessorListener',['../classAudioProcessorListener.html',1,'']]],
+  ['audioprocessorparameter_407',['AudioProcessorParameter',['../classAudioProcessorParameter.html',1,'']]],
+  ['audioprocessorparametergroup_408',['AudioProcessorParameterGroup',['../classAudioProcessorParameterGroup.html',1,'']]],
+  ['audioprocessorparameternode_409',['AudioProcessorParameterNode',['../classAudioProcessorParameterGroup_1_1AudioProcessorParameterNode.html',1,'AudioProcessorParameterGroup']]],
+  ['audioprocessorparameterwithid_410',['AudioProcessorParameterWithID',['../classAudioProcessorParameterWithID.html',1,'']]],
+  ['audioprocessorparameterwithidattributes_411',['AudioProcessorParameterWithIDAttributes',['../classAudioProcessorParameterWithIDAttributes.html',1,'']]],
+  ['audioprocessorplayer_412',['AudioProcessorPlayer',['../classAudioProcessorPlayer.html',1,'']]],
+  ['audioprocessorvaluetreestate_413',['AudioProcessorValueTreeState',['../classAudioProcessorValueTreeState.html',1,'']]],
+  ['audioprocessorvaluetreestateparameterattributes_414',['AudioProcessorValueTreeStateParameterAttributes',['../classAudioProcessorValueTreeStateParameterAttributes.html',1,'']]],
+  ['audiosource_415',['AudioSource',['../classAudioSource.html',1,'']]],
+  ['audiosourcechannelinfo_416',['AudioSourceChannelInfo',['../structAudioSourceChannelInfo.html',1,'']]],
+  ['audiosourceplayer_417',['AudioSourcePlayer',['../classAudioSourcePlayer.html',1,'']]],
+  ['audiosubsectionreader_418',['AudioSubsectionReader',['../classAudioSubsectionReader.html',1,'']]],
+  ['audiothumbnail_419',['AudioThumbnail',['../classAudioThumbnail.html',1,'']]],
+  ['audiothumbnailbase_420',['AudioThumbnailBase',['../classAudioThumbnailBase.html',1,'']]],
+  ['audiothumbnailcache_421',['AudioThumbnailCache',['../classAudioThumbnailCache.html',1,'']]],
+  ['audiotransportsource_422',['AudioTransportSource',['../classAudioTransportSource.html',1,'']]],
+  ['audiounitclient_423',['AudioUnitClient',['../structExtensionsVisitor_1_1AudioUnitClient.html',1,'ExtensionsVisitor']]],
+  ['audiounitpluginformat_424',['AudioUnitPluginFormat',['../classAudioUnitPluginFormat.html',1,'']]],
+  ['audiovisualisercomponent_425',['AudioVisualiserComponent',['../classAudioVisualiserComponent.html',1,'']]],
+  ['audioworkgroup_426',['AudioWorkgroup',['../classAudioWorkgroup.html',1,'']]],
   ['availableservicelist_427',['AvailableServiceList',['../structNetworkServiceDiscovery_1_1AvailableServiceList.html',1,'NetworkServiceDiscovery']]]
 ];
