@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['gain_0',['Gain',['../classdsp_1_1Gain.html',1,'dsp']]],
+  ['gain_0',['Gain',['../classjuce_1_1dsp_1_1Gain.html',1,'juce::dsp']]],
   ['genericaudioprocessoreditor_1',['GenericAudioProcessorEditor',['../classGenericAudioProcessorEditor.html',1,'']]],
   ['genericinterpolator_2',['GenericInterpolator',['../classGenericInterpolator.html',1,'']]],
   ['genericscopedlock_3',['GenericScopedLock',['../classGenericScopedLock.html',1,'']]],
