@@ -64,30 +64,30 @@ var searchData=
   ['heapblock_3c_20double_20_3e_61',['HeapBlock&lt; double &gt;',['../classHeapBlock.html',1,'']]],
   ['heapblock_3c_20dragimagecomponent_20_2a_20_3e_62',['HeapBlock&lt; DragImageComponent * &gt;',['../classHeapBlock.html',1,'']]],
   ['heapblock_3c_20drawablebutton_20_2a_20_3e_63',['HeapBlock&lt; DrawableButton * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20dsp_3a_3afirstordertptfilter_3c_20sampletype_20_3e_20_2a_20_3e_64',['HeapBlock&lt; dsp::FirstOrderTPTFilter&lt; SampleType &gt; * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20file_20_3e_65',['HeapBlock&lt; File &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20filebrowserlistener_20_2a_20_3e_66',['HeapBlock&lt; FileBrowserListener * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20filenamecomponentlistener_20_2a_20_3e_67',['HeapBlock&lt; FilenameComponentListener * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20filterstate_20_3e_68',['HeapBlock&lt; FilterState &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20flexitem_20_3e_69',['HeapBlock&lt; FlexItem &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20float_20_2a_20_3e_70',['HeapBlock&lt; float * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20float_20_3e_71',['HeapBlock&lt; float &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20floatingtype_20_3e_72',['HeapBlock&lt; FloatingType &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20floattype_20_3e_73',['HeapBlock&lt; FloatType &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20focuschangelistener_20_2a_20_3e_74',['HeapBlock&lt; FocusChangeListener * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20glyphinfo_20_2a_20_3e_75',['HeapBlock&lt; GlyphInfo * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20grid_3a_3atrackinfo_20_3e_76',['HeapBlock&lt; Grid::TrackInfo &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20griditem_20_3e_77',['HeapBlock&lt; GridItem &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20hashentry_20_2a_20_3e_78',['HeapBlock&lt; HashEntry * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20iircoefficients_20_2a_20_3e_79',['HeapBlock&lt; IIRCoefficients * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20iirfilter_20_2a_20_3e_80',['HeapBlock&lt; IIRFilter * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20imagepixeldata_3a_3alistener_20_2a_20_3e_81',['HeapBlock&lt; ImagePixelData::Listener * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20inapppurchases_3a_3adownload_20_2a_20_3e_82',['HeapBlock&lt; InAppPurchases::Download * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20inapppurchases_3a_3alistener_20_2a_20_3e_83',['HeapBlock&lt; InAppPurchases::Listener * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20int_20_3e_84',['HeapBlock&lt; int &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20item_20_2a_20_3e_85',['HeapBlock&lt; Item * &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20item_20_3e_86',['HeapBlock&lt; Item &gt;',['../classHeapBlock.html',1,'']]],
-  ['heapblock_3c_20itemlayoutproperties_20_2a_20_3e_87',['HeapBlock&lt; ItemLayoutProperties * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20file_20_3e_64',['HeapBlock&lt; File &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20filebrowserlistener_20_2a_20_3e_65',['HeapBlock&lt; FileBrowserListener * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20filenamecomponentlistener_20_2a_20_3e_66',['HeapBlock&lt; FilenameComponentListener * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20filterstate_20_3e_67',['HeapBlock&lt; FilterState &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20flexitem_20_3e_68',['HeapBlock&lt; FlexItem &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20float_20_2a_20_3e_69',['HeapBlock&lt; float * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20float_20_3e_70',['HeapBlock&lt; float &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20floatingtype_20_3e_71',['HeapBlock&lt; FloatingType &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20floattype_20_3e_72',['HeapBlock&lt; FloatType &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20focuschangelistener_20_2a_20_3e_73',['HeapBlock&lt; FocusChangeListener * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20glyphinfo_20_2a_20_3e_74',['HeapBlock&lt; GlyphInfo * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20grid_3a_3atrackinfo_20_3e_75',['HeapBlock&lt; Grid::TrackInfo &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20griditem_20_3e_76',['HeapBlock&lt; GridItem &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20hashentry_20_2a_20_3e_77',['HeapBlock&lt; HashEntry * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20iircoefficients_20_2a_20_3e_78',['HeapBlock&lt; IIRCoefficients * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20iirfilter_20_2a_20_3e_79',['HeapBlock&lt; IIRFilter * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20imagepixeldata_3a_3alistener_20_2a_20_3e_80',['HeapBlock&lt; ImagePixelData::Listener * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20inapppurchases_3a_3adownload_20_2a_20_3e_81',['HeapBlock&lt; InAppPurchases::Download * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20inapppurchases_3a_3alistener_20_2a_20_3e_82',['HeapBlock&lt; InAppPurchases::Listener * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20int_20_3e_83',['HeapBlock&lt; int &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20item_20_2a_20_3e_84',['HeapBlock&lt; Item * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20item_20_3e_85',['HeapBlock&lt; Item &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20itemlayoutproperties_20_2a_20_3e_86',['HeapBlock&lt; ItemLayoutProperties * &gt;',['../classHeapBlock.html',1,'']]],
+  ['heapblock_3c_20juce_3a_3adsp_3a_3afirstordertptfilter_3c_20sampletype_20_3e_20_2a_20_3e_87',['HeapBlock&lt; juce::dsp::FirstOrderTPTFilter&lt; SampleType &gt; * &gt;',['../classHeapBlock.html',1,'']]],
   ['heapblock_3c_20keypress_20_3e_88',['HeapBlock&lt; KeyPress &gt;',['../classHeapBlock.html',1,'']]],
   ['heapblock_3c_20keypresstime_20_2a_20_3e_89',['HeapBlock&lt; KeyPressTime * &gt;',['../classHeapBlock.html',1,'']]],
   ['heapblock_3c_20knownpluginlist_3a_3aplugintree_20_2a_20_3e_90',['HeapBlock&lt; KnownPluginList::PluginTree * &gt;',['../classHeapBlock.html',1,'']]],
@@ -175,9 +175,8 @@ var searchData=
   ['heavyweightleakedobjectdetector_172',['HeavyweightLeakedObjectDetector',['../classHeavyweightLeakedObjectDetector.html',1,'']]],
   ['hexparser_173',['HexParser',['../structCharacterFunctions_1_1HexParser.html',1,'CharacterFunctions']]],
   ['highresolutiontimer_174',['HighResolutionTimer',['../classHighResolutionTimer.html',1,'']]],
-  ['hostdriveneventloop_175',['HostDrivenEventLoop',['../classHostDrivenEventLoop.html',1,'']]],
-  ['hostedaudioprocessorparameter_176',['HostedAudioProcessorParameter',['../structHostedAudioProcessorParameter.html',1,'']]],
-  ['hostprovidedcontextmenu_177',['HostProvidedContextMenu',['../structHostProvidedContextMenu.html',1,'']]],
-  ['hwndcomponent_178',['HWNDComponent',['../classHWNDComponent.html',1,'']]],
-  ['hyperlinkbutton_179',['HyperlinkButton',['../classHyperlinkButton.html',1,'']]]
+  ['hostedaudioprocessorparameter_175',['HostedAudioProcessorParameter',['../structHostedAudioProcessorParameter.html',1,'']]],
+  ['hostprovidedcontextmenu_176',['HostProvidedContextMenu',['../structHostProvidedContextMenu.html',1,'']]],
+  ['hwndcomponent_177',['HWNDComponent',['../classHWNDComponent.html',1,'']]],
+  ['hyperlinkbutton_178',['HyperlinkButton',['../classHyperlinkButton.html',1,'']]]
 ];
