@@ -1,13 +1,13 @@
 var searchData=
 [
   ['filechooserflags_0',['FileChooserFlags',['../classFileBrowserComponent.html#a32888a950cc0e51c8e1350f53bea43d6',1,'FileBrowserComponent']]],
-  ['filtertype_1',['FilterType',['../classdsp_1_1Oversampling.html#ac3d048707b7807badec0df770c9778f8',1,'dsp::Oversampling']]],
-  ['firstordertptfiltertype_2',['FirstOrderTPTFilterType',['../namespacedsp.html#ae95dedb418a8687b6f966f9dc92a4603',1,'dsp']]],
-  ['flags_3',['Flags',['../classJustification.html#a1f8c07756c56fe8f31ed44964e51bfbc',1,'Justification::Flags'],['../classRectanglePlacement.html#afd5464553fd6bb41d697f3fc1d7427ed',1,'RectanglePlacement::Flags'],['../classModifierKeys.html#acdd2a85defa6a705d74e1a63d193678b',1,'ModifierKeys::Flags']]],
+  ['filtertype_1',['FilterType',['../classjuce_1_1dsp_1_1Oversampling.html#a3948fb7c9d928b594f55617aac1e77be',1,'juce::dsp::Oversampling']]],
+  ['firstordertptfiltertype_2',['FirstOrderTPTFilterType',['../namespacejuce_1_1dsp.html#a09c9af8774596446ec8f4633a5dd6890',1,'juce::dsp']]],
+  ['flags_3',['flags',['../classJustification.html#a1f8c07756c56fe8f31ed44964e51bfbc',1,'Justification::Flags'],['../classRectanglePlacement.html#afd5464553fd6bb41d697f3fc1d7427ed',1,'RectanglePlacement::Flags'],['../classModifierKeys.html#acdd2a85defa6a705d74e1a63d193678b',1,'ModifierKeys::Flags']]],
   ['focuschangedirection_4',['FocusChangeDirection',['../classComponent.html#ab18a6aca762ad01c908b8023cef6e6e4',1,'Component']]],
   ['focuschangetype_5',['FocusChangeType',['../classComponent.html#a7fd775ea6b1190d5d694fdffa539dfac',1,'Component']]],
   ['focuscontainertype_6',['FocusContainerType',['../classComponent.html#af4b602b33a2f82e39560fcffb6a2bd9e',1,'Component']]],
-  ['followsymlinks_7',['FollowSymlinks',['../classFile.html#a0a1de7b7cf65e7502cac315b3d180aec',1,'File::FollowSymlinks'],['../classZipFile.html#a16ad335c8def5a80206070a64a42685e',1,'ZipFile::FollowSymlinks']]],
+  ['followsymlinks_7',['followsymlinks',['../classFile.html#a0a1de7b7cf65e7502cac315b3d180aec',1,'File::FollowSymlinks'],['../classZipFile.html#a16ad335c8def5a80206070a64a42685e',1,'ZipFile::FollowSymlinks']]],
   ['fontstyleflags_8',['FontStyleFlags',['../classFont.html#a52a35b5dc1e6f782e25283c9283bae4f',1,'Font']]],
   ['format_9',['Format',['../classGZIPDecompressorInputStream.html#a293d005b03d528a89ec13cfb07e31f94',1,'GZIPDecompressorInputStream']]],
   ['frameratetype_10',['FrameRateType',['../classAudioPlayHead.html#a9afad1749c8002945b2a6921eef92b25',1,'AudioPlayHead']]]
