@@ -1,12 +1,12 @@
 var searchData=
 [
-  ['pannerrule_0',['PannerRule',['../namespacedsp.html#acdb6eea4e47ecc11207df3cf54485518',1,'dsp']]],
+  ['pannerrule_0',['PannerRule',['../namespacejuce_1_1dsp.html#a3f5c092cf541b9596716e8f04ed14ad2',1,'juce::dsp']]],
   ['parameterhandling_1',['ParameterHandling',['../classURL.html#adc152773646c192dd08e1bde7c54665b',1,'URL']]],
   ['pathelementtype_2',['PathElementType',['../classPath_1_1Iterator.html#a62b1a329e3fdbcbdad78bb6c90c7bcfd',1,'Path::Iterator']]],
   ['permissionid_3',['PermissionID',['../classRuntimePermissions.html#ae35d63b8c00dab34a1546fd1eef90878',1,'RuntimePermissions']]],
   ['pixelformat_4',['PixelFormat',['../classImage.html#ab47b5746d2df286ae6f8da6af5463c01',1,'Image']]],
   ['popupdirection_5',['PopupDirection',['../classPopupMenu_1_1Options.html#a1bcdbc585618aba656891d7bd7e65b79',1,'PopupMenu::Options']]],
-  ['priority_6',['Priority',['../structPushNotifications_1_1Notification.html#a90a1b86b07e15d5cc253e904c66e8b70',1,'PushNotifications::Notification']]],
+  ['priority_6',['priority',['../classThread.html#aae22d3d18dffe1adbbc2baf564e0383b',1,'Thread::Priority'],['../structPushNotifications_1_1Notification.html#a90a1b86b07e15d5cc253e904c66e8b70',1,'PushNotifications::Notification::Priority']]],
   ['processingprecision_7',['ProcessingPrecision',['../classAudioProcessor.html#a212c3670b59976559237cbf629af275f',1,'AudioProcessor']]],
   ['processpriority_8',['ProcessPriority',['../classProcess.html#ad7b18ceb7a8c0a2b6b71856894feb6ef',1,'Process']]]
 ];
