@@ -6,6 +6,6 @@ var searchData=
   ['colour_3',['colour',['../group__juce__graphics-colour.html',1,'']]],
   ['commands_4',['commands',['../group__juce__gui__basics-commands.html',1,'']]],
   ['components_5',['components',['../group__juce__gui__basics-components.html',1,'']]],
-  ['containers_6',['containers',['../group__juce__core-containers.html',1,'(Global Namespace)'],['../group__juce__dsp-containers.html',1,'(Global Namespace)']]],
+  ['containers_6',['containers',['../group__juce__dsp-containers.html',1,'containers'],['../group__juce__core-containers.html',1,'containers']]],
   ['contexts_7',['contexts',['../group__juce__graphics-contexts.html',1,'']]]
 ];
