@@ -2,7 +2,7 @@ var searchData=
 [
   ['desktop_0',['desktop',['../group__juce__gui__basics-desktop.html',1,'']]],
   ['destinations_1',['destinations',['../group__juce__analytics-destinations.html',1,'']]],
-  ['detail_2',['detail',['../group__juce__audio__plugin__client-detail.html',1,'(Global Namespace)'],['../group__juce__gui__basics-detail.html',1,'(Global Namespace)']]],
+  ['detail_2',['detail',['../group__juce__gui__basics-detail.html',1,'detail'],['../group__juce__audio__plugin__client-detail.html',1,'detail']]],
   ['documents_3',['documents',['../group__juce__gui__extra-documents.html',1,'']]],
   ['drawables_4',['drawables',['../group__juce__gui__basics-drawables.html',1,'']]]
 ];
