@@ -1,17 +1,17 @@
 var searchData=
 [
-  ['saddlebrown_0',['saddlebrown',['../namespaceColours.html#a90965658d26df6d0ca73ee3595ae0806',1,'Colours']]],
+  ['saddlebrown_0',['saddlebrown',['../namespacejuce_1_1Colours.html#ad8062e423e2bc8b795d406aea1e92efe',1,'juce::Colours']]],
   ['safeareainsets_1',['safeAreaInsets',['../structDisplays_1_1Display.html#a1d9c2cbdd9e267917f05e4b9244496f1',1,'Displays::Display']]],
-  ['salmon_2',['salmon',['../namespaceColours.html#a5d926bfb763818a5f64344a09b612ed1',1,'Colours']]],
+  ['salmon_2',['salmon',['../namespacejuce_1_1Colours.html#addf22727c2c18ad7cfe3f611841da2fa',1,'juce::Colours']]],
   ['sampleposition_3',['samplePosition',['../structMidiMessageMetadata.html#a29f3e866c6b86f0f0947f81ecf390b57',1,'MidiMessageMetadata']]],
-  ['samplerate_4',['sampleRate',['../structdsp_1_1ProcessSpec.html#a6c7c39e922722be2518a973f76a48fa6',1,'dsp::ProcessSpec::sampleRate'],['../classAudioFormatReader.html#aafcd07b3ac08e83c019621cd8cd0c7c5',1,'AudioFormatReader::sampleRate'],['../classAudioFormatWriter.html#aafefbda90e2a58cb057e89e995decfd2',1,'AudioFormatWriter::sampleRate'],['../structAudioDeviceManager_1_1AudioDeviceSetup.html#afa56530d7a661131d8891f7b9874fcd1',1,'AudioDeviceManager::AudioDeviceSetup::sampleRate']]],
-  ['sandybrown_5',['sandybrown',['../namespaceColours.html#aca7d5a81d72547917b11b3476a201653',1,'Colours']]],
+  ['samplerate_4',['samplerate',['../structjuce_1_1dsp_1_1ProcessSpec.html#ad802311696146be56286e7a04cf0ff0e',1,'juce::dsp::ProcessSpec::sampleRate'],['../classAudioFormatReader.html#aafcd07b3ac08e83c019621cd8cd0c7c5',1,'AudioFormatReader::sampleRate'],['../classAudioFormatWriter.html#aafefbda90e2a58cb057e89e995decfd2',1,'AudioFormatWriter::sampleRate'],['../structAudioDeviceManager_1_1AudioDeviceSetup.html#afa56530d7a661131d8891f7b9874fcd1',1,'AudioDeviceManager::AudioDeviceSetup::sampleRate']]],
+  ['sandybrown_5',['sandybrown',['../namespacejuce_1_1Colours.html#a7942793ceccdeabaa87d4eebd781d4ac',1,'juce::Colours']]],
   ['scalar_6',['scalar',['../classQuaternion.html#adfe519277223a4cb9321dc7f0d3b5cca',1,'Quaternion']]],
   ['scale_7',['scale',['../structDisplays_1_1Display.html#a611a3fe584fa04e86538866af0e5d788',1,'Displays::Display']]],
   ['scalefactorlisteners_8',['scaleFactorListeners',['../classComponentPeer.html#a3c815b759167f87c6c9aead83b737b3f',1,'ComponentPeer']]],
   ['scopeuid_9',['scopeUID',['../structExpression_1_1Symbol.html#aaddddb4fd2bad7fcce78adce69ba91d8',1,'Expression::Symbol']]],
-  ['seagreen_10',['seagreen',['../namespaceColours.html#a7e606ecd6ff3a930c83d9ef00e1b8935',1,'Colours']]],
-  ['seashell_11',['seashell',['../namespaceColours.html#ac4b8902af30427b5318372cfb896a656',1,'Colours']]],
+  ['seagreen_10',['seagreen',['../namespacejuce_1_1Colours.html#a985ebc7adf648f8f0a0560e2169d4e1a',1,'juce::Colours']]],
+  ['seashell_11',['seashell',['../namespacejuce_1_1Colours.html#aef40e9777b9ad1b700075a43935e2bb7',1,'juce::Colours']]],
   ['senddismissaction_12',['sendDismissAction',['../structPushNotifications_1_1Settings_1_1Category.html#aa90e5793a6bd2176dc4cf3a316eb941b',1,'PushNotifications::Settings::Category']]],
   ['settings_13',['settings',['../classStandalonePluginHolder.html#a58375e902a8f0e9d079ff54abf763ac5',1,'StandalonePluginHolder']]],
   ['sharedcontainer_14',['sharedContainer',['../classURL_1_1DownloadTaskOptions.html#a4651101ae8413a43355d9e1d4a28779a',1,'URL::DownloadTaskOptions']]],
@@ -21,24 +21,24 @@ var searchData=
   ['shouldautocancel_18',['shouldAutoCancel',['../structPushNotifications_1_1Notification.html#a54c4fda3356e2eb72900ec2f4235ad4f',1,'PushNotifications::Notification']]],
   ['shouldbreakafter_19',['shouldBreakAfter',['../structPopupMenu_1_1Item.html#a17608385ca850ad15212f5e9f23b38a5',1,'PopupMenu::Item']]],
   ['shouldmuteinput_20',['shouldMuteInput',['../classStandalonePluginHolder.html#aa908cd3ed76d0af8c7cc47bb644377d4',1,'StandalonePluginHolder']]],
-  ['sienna_21',['sienna',['../namespaceColours.html#a8e4df5d9ebbb4b670a97e5da3b8c16a1',1,'Colours']]],
-  ['silver_22',['silver',['../namespaceColours.html#aa79eb37d356e37bfaa6a6284d83d7850',1,'Colours']]],
-  ['simdnumelements_23',['SIMDNumElements',['../structdsp_1_1SIMDRegister.html#a3a9f728b56ef1b9fd3fceddb51259918',1,'dsp::SIMDRegister']]],
-  ['simdregistersize_24',['SIMDRegisterSize',['../structdsp_1_1SIMDRegister.html#a295428a84f540c2442e2c476abc49800',1,'dsp::SIMDRegister']]],
-  ['size_25',['size',['../classImage_1_1BitmapData.html#a60d26c041c2e0269be4ae728a527ea75',1,'Image::BitmapData']]],
+  ['sienna_21',['sienna',['../namespacejuce_1_1Colours.html#a389d26cbcf0255382480f33a14467d7f',1,'juce::Colours']]],
+  ['silver_22',['silver',['../namespacejuce_1_1Colours.html#a18330e8d42f099bc915d653f85b99c30',1,'juce::Colours']]],
+  ['simdnumelements_23',['SIMDNumElements',['../structjuce_1_1dsp_1_1SIMDRegister.html#a8de80f3d8426dce32fdb6d1f26640efc',1,'juce::dsp::SIMDRegister']]],
+  ['simdregistersize_24',['SIMDRegisterSize',['../structjuce_1_1dsp_1_1SIMDRegister.html#a5518ffb582ca4b24389083b162731d0b',1,'juce::dsp::SIMDRegister']]],
+  ['size_25',['size',['../classImage_1_1BitmapData.html#a60d26c041c2e0269be4ae728a527ea75',1,'Image::BitmapData::size'],['../structSerialisationSize.html#a56b2566b9b32c26b0387c59540d95bd6',1,'SerialisationSize::size']]],
   ['skew_26',['skew',['../classNormalisableRange.html#a740639acf2157636fce16138a51bbfa3',1,'NormalisableRange']]],
-  ['skyblue_27',['skyblue',['../namespaceColours.html#a205799e7de1ccdc71fe5e739e764ebfd',1,'Colours']]],
-  ['slateblue_28',['slateblue',['../namespaceColours.html#ae17019b7c584a4235d2cb9969dcfbd1d',1,'Colours']]],
-  ['slategrey_29',['slategrey',['../namespaceColours.html#aa56a25e88a248e9174f92c98d94857e2',1,'Colours']]],
+  ['skyblue_27',['skyblue',['../namespacejuce_1_1Colours.html#a1c35b867c1744cbb26170d39d2fa3dce',1,'juce::Colours']]],
+  ['slateblue_28',['slateblue',['../namespacejuce_1_1Colours.html#ae80d2e35c376b45c5e2a62a5df1eab4d',1,'juce::Colours']]],
+  ['slategrey_29',['slategrey',['../namespacejuce_1_1Colours.html#a037e21e743a5638a36ea46f17e4ae63e',1,'juce::Colours']]],
   ['slider_30',['slider',['../classSliderPropertyComponent.html#ae379d1c2bbcdab0d687697c9dfc36f9b',1,'SliderPropertyComponent']]],
   ['sliderbounds_31',['sliderBounds',['../structSlider_1_1SliderLayout.html#a40ee690d7af050cd1d59b75142234817',1,'Slider::SliderLayout']]],
-  ['snow_32',['snow',['../namespaceColours.html#a5f8c43c69872971f4bddb68a780dd2bf',1,'Colours']]],
+  ['snow_32',['snow',['../namespacejuce_1_1Colours.html#a7655cdfd146444a61167d9de5ae51663',1,'juce::Colours']]],
   ['sounds_33',['sounds',['../classSynthesiser.html#ac64f99f204a1d5a567422cd9d5217081',1,'Synthesiser']]],
-  ['soundtoplay_34',['soundToPlay',['../structPushNotifications_1_1Channel.html#aa159faa73985e53ee97979ba56d9b767',1,'PushNotifications::Channel::soundToPlay'],['../structPushNotifications_1_1Notification.html#a3bc57c2d4c760a1eeefd90fa05bcd207',1,'PushNotifications::Notification::soundToPlay']]],
+  ['soundtoplay_34',['soundtoplay',['../structPushNotifications_1_1Channel.html#aa159faa73985e53ee97979ba56d9b767',1,'PushNotifications::Channel::soundToPlay'],['../structPushNotifications_1_1Notification.html#a3bc57c2d4c760a1eeefd90fa05bcd207',1,'PushNotifications::Notification::soundToPlay']]],
   ['source_35',['source',['../classMouseEvent.html#a4f70eb92a29dc0acfa9f782388e254bc',1,'MouseEvent::source'],['../structAudioProcessorGraph_1_1Connection.html#a05813b379dcc6ac0431f4492e6bb3b31',1,'AudioProcessorGraph::Connection::source']]],
   ['sourcecomponent_36',['sourceComponent',['../classDragAndDropTarget_1_1SourceDetails.html#ad64cf556308af58fb6873d16f4a590de',1,'DragAndDropTarget::SourceDetails']]],
   ['spacekey_37',['spaceKey',['../classKeyPress.html#a60f802af5aff465d7ff910009608e343',1,'KeyPress']]],
-  ['springgreen_38',['springgreen',['../namespaceColours.html#ac183fa0ff07f05bb73d852b4cdf8911b',1,'Colours']]],
+  ['springgreen_38',['springgreen',['../namespacejuce_1_1Colours.html#a177b8638908c434e97d5f9b8c9b69b9c',1,'juce::Colours']]],
   ['sqrt2_39',['sqrt2',['../structMathConstants.html#ad5a94be39095bba9fd165df2c7435f41',1,'MathConstants']]],
   ['start_40',['start',['../structGridItem_1_1StartAndEndProperty.html#a1f4e27e7a91ec09563b7655a3b4f5ccf',1,'GridItem::StartAndEndProperty::start'],['../structTextDiff_1_1Change.html#ac72e9e25d35530fac7837a2d22c31958',1,'TextDiff::Change::start'],['../classNormalisableRange.html#adc186176e94c6f80eb2c626384054fe3',1,'NormalisableRange::start']]],
   ['startangleradians_41',['startAngleRadians',['../structSlider_1_1RotaryParameters.html#a1b4090a3f77b0183b1c847525f4edb8a',1,'Slider::RotaryParameters']]],
@@ -48,16 +48,16 @@ var searchData=
   ['startpos_45',['startPos',['../classRelativePointPath_1_1StartSubPath.html#afcaa4975b6ef2fcc78e99b873a38d2d2',1,'RelativePointPath::StartSubPath']]],
   ['startsample_46',['startSample',['../structAudioSourceChannelInfo.html#a42e88ccc05d4893015e2415785390259',1,'AudioSourceChannelInfo']]],
   ['starttime_47',['startTime',['../structUnitTestRunner_1_1TestResult.html#a4a9729ea0d39217a16dd619db024a398',1,'UnitTestRunner::TestResult']]],
-  ['state_48',['state',['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state'],['../structdsp_1_1ProcessorDuplicator.html#a5907f78806648c78d794e1f16943df9d',1,'dsp::ProcessorDuplicator::state'],['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state']]],
+  ['state_48',['state',['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state'],['../structjuce_1_1dsp_1_1ProcessorDuplicator.html#acb3791e4d5480e67205cad6345ee4b12',1,'juce::dsp::ProcessorDuplicator::state'],['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state']]],
   ['statefilechooser_49',['stateFileChooser',['../classStandalonePluginHolder.html#a5f6cf68a9218c9f93837bc13b7841393',1,'StandalonePluginHolder']]],
   ['statestack_50',['stateStack',['../classLowLevelGraphicsPostScriptRenderer.html#a95a55fd1cd7588048a37ac86fa384849',1,'LowLevelGraphicsPostScriptRenderer']]],
-  ['steelblue_51',['steelblue',['../namespaceColours.html#a588c5015b8beea03960fd220c973e70d',1,'Colours']]],
+  ['steelblue_51',['steelblue',['../namespacejuce_1_1Colours.html#a3076663dec5ce535595171500c04b783',1,'juce::Colours']]],
   ['stencilbufferbits_52',['stencilBufferBits',['../classOpenGLPixelFormat.html#aa94f3f667e41465ea29b6f259d9abf8b',1,'OpenGLPixelFormat']]],
   ['stopatend_53',['stopAtEnd',['../structSlider_1_1RotaryParameters.html#a2e705ed5eb148f3f3eb1e89a72ff634f',1,'Slider::RotaryParameters']]],
   ['stopkey_54',['stopKey',['../classKeyPress.html#a4ebc694e95335f25418c99eb2235d815',1,'KeyPress']]],
   ['storageformat_55',['storageFormat',['../structPropertiesFile_1_1Options.html#aed68b3ff89a6943aeac93af26effec2d',1,'PropertiesFile::Options']]],
   ['string_56',['string',['../classOSCTypes.html#ad427b15ae32b26b2e0c28f0932eed263',1,'OSCTypes']]],
-  ['stringrange_57',['stringRange',['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange'],['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange']]],
+  ['stringrange_57',['stringrange',['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange'],['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange']]],
   ['strings_58',['strings',['../classStringArray.html#ac10f010a31e1dcd6220d278a1603e37a',1,'StringArray']]],
   ['strokepath_59',['strokePath',['../classDrawableShape.html#a9400e1628d38b4719c211da4158bc2ff',1,'DrawableShape']]],
   ['stroketype_60',['strokeType',['../classDrawableShape.html#af636e2ff4b818d2b51994291facb30f6',1,'DrawableShape']]],
