@@ -1,12 +1,12 @@
 var searchData=
 [
-  ['magenta_0',['magenta',['../namespaceColours.html#a4ccacdd79d72dcd21ce9480673910e4a',1,'Colours']]],
+  ['magenta_0',['magenta',['../namespacejuce_1_1Colours.html#a450e3cc8eb6fd2524f3f9472e3d9c0c9',1,'juce::Colours']]],
   ['manufacturername_1',['manufacturerName',['../classPluginDescription.html#aa8c02c784dc999a1043877b29795fff0',1,'PluginDescription']]],
   ['map_2',['map',['../classMemoryMappedAudioFormatReader.html#abac7449f98c330b9a633210af2145c0f',1,'MemoryMappedAudioFormatReader']]],
   ['mappedsection_3',['mappedSection',['../classMemoryMappedAudioFormatReader.html#a33d4ab9328d5a4e588053c894b7a8c45',1,'MemoryMappedAudioFormatReader']]],
   ['margin_4',['margin',['../classGridItem.html#aab6d3baf29b7fdb0ecbdd519ae4eafb2',1,'GridItem::margin'],['../classFlexItem.html#a995f3c4d01fc78a564a2d4db0e909532',1,'FlexItem::margin']]],
   ['markertag_5',['markerTag',['../classMarkerList_1_1ValueTreeWrapper.html#a6ee3f514e213161c74b047b9bc6011d2',1,'MarkerList::ValueTreeWrapper']]],
-  ['maroon_6',['maroon',['../namespaceColours.html#afb8d50495ddad76d8a45e385e88387a4',1,'Colours']]],
+  ['maroon_6',['maroon',['../namespacejuce_1_1Colours.html#a7e944323d68d3fdb7f6ba294a65c6c9b',1,'juce::Colours']]],
   ['masterpitchbendrange_7',['masterPitchbendRange',['../structMPEZone.html#a630f3a2724d4f64f94f83907de9dfd84',1,'MPEZone']]],
   ['mat_8',['mat',['../classMatrix3D.html#ad7e9eecc94c0a33a029a5de12c5c056b',1,'Matrix3D']]],
   ['mat00_9',['mat00',['../classAffineTransform.html#a1e675f5137df72253566699cd385c7ad',1,'AffineTransform']]],
@@ -16,36 +16,36 @@ var searchData=
   ['mat11_13',['mat11',['../classAffineTransform.html#a808a65da0b88a09f0e2ac752fd2648ef',1,'AffineTransform']]],
   ['mat12_14',['mat12',['../classAffineTransform.html#ae26718eb62e1240ad8f800f7e7ce3a74',1,'AffineTransform']]],
   ['max_15',['max',['../structAccessibilityValueInterface_1_1AccessibleValueRange_1_1MinAndMax.html#af5881a5f3999c1e7eecec18fa94b589a',1,'AccessibilityValueInterface::AccessibleValueRange::MinAndMax::max'],['../structPushNotifications_1_1Notification_1_1Progress.html#a7b640edb7dd3f94da1a01b3e33c65451',1,'PushNotifications::Notification::Progress::max']]],
-  ['maxheight_16',['maxHeight',['../classFlexItem.html#a166fa48e4268692cce0419f8ed5ad56a',1,'FlexItem::maxHeight'],['../classGridItem.html#aebe1c6bf8c616570acf4021b32d9572a',1,'GridItem::maxHeight']]],
-  ['maximumblocksize_17',['maximumBlockSize',['../structdsp_1_1ProcessSpec.html#aa57b782ce7ef5dd262ed688b39d7ac26',1,'dsp::ProcessSpec']]],
+  ['maxheight_16',['maxheight',['../classFlexItem.html#a166fa48e4268692cce0419f8ed5ad56a',1,'FlexItem::maxHeight'],['../classGridItem.html#aebe1c6bf8c616570acf4021b32d9572a',1,'GridItem::maxHeight']]],
+  ['maximumblocksize_17',['maximumBlockSize',['../structjuce_1_1dsp_1_1ProcessSpec.html#af298a8ee9114572706aa59de7caec09e',1,'juce::dsp::ProcessSpec']]],
   ['maximumexecutiontime_18',['maximumExecutionTime',['../classJavascriptEngine.html#a4a08635cda469509d851264f9fcf2c46',1,'JavascriptEngine']]],
   ['maximumseconds_19',['maximumSeconds',['../structPerformanceCounter_1_1Statistics.html#a560f9606307b0a9a7b4f44d839c80f61',1,'PerformanceCounter::Statistics']]],
-  ['maxwidth_20',['maxWidth',['../classGridItem.html#aa9141fbfdf1ca5bb5246cdc144095202',1,'GridItem::maxWidth'],['../classFlexItem.html#ae1b6c839d1aefdedd7e3a3c4fa3667aa',1,'FlexItem::maxWidth']]],
-  ['mediumaquamarine_21',['mediumaquamarine',['../namespaceColours.html#a2fc4010040dc31a841eb0b3707ab0b5c',1,'Colours']]],
-  ['mediumblue_22',['mediumblue',['../namespaceColours.html#adf9870115a1dbffd076a9b6acd62169e',1,'Colours']]],
-  ['mediumorchid_23',['mediumorchid',['../namespaceColours.html#a4a534941933943929bbaed4b59a2a74a',1,'Colours']]],
-  ['mediumpurple_24',['mediumpurple',['../namespaceColours.html#a0b9b28c1473f60e8ee5de2799df16bdc',1,'Colours']]],
-  ['mediumseagreen_25',['mediumseagreen',['../namespaceColours.html#a023eace2149cc32997fa14eff7b2defc',1,'Colours']]],
-  ['mediumslateblue_26',['mediumslateblue',['../namespaceColours.html#a0af669644674591dbd64d8416ff03a01',1,'Colours']]],
-  ['mediumspringgreen_27',['mediumspringgreen',['../namespaceColours.html#ae399e13cc3a82957928112e32b77b333',1,'Colours']]],
-  ['mediumturquoise_28',['mediumturquoise',['../namespaceColours.html#a0575b0daad0652a6d3b265dae189d273',1,'Colours']]],
-  ['mediumvioletred_29',['mediumvioletred',['../namespaceColours.html#a7f462d40c47140c28583d001da00ebe8',1,'Colours']]],
+  ['maxwidth_20',['maxwidth',['../classGridItem.html#aa9141fbfdf1ca5bb5246cdc144095202',1,'GridItem::maxWidth'],['../classFlexItem.html#ae1b6c839d1aefdedd7e3a3c4fa3667aa',1,'FlexItem::maxWidth']]],
+  ['mediumaquamarine_21',['mediumaquamarine',['../namespacejuce_1_1Colours.html#ab8de10333465ef608d2222fe2a4778c3',1,'juce::Colours']]],
+  ['mediumblue_22',['mediumblue',['../namespacejuce_1_1Colours.html#aa54c84ca3da00cf22f84dcf54836b036',1,'juce::Colours']]],
+  ['mediumorchid_23',['mediumorchid',['../namespacejuce_1_1Colours.html#aac28380dbaaa0245aa9cc3843f3061d8',1,'juce::Colours']]],
+  ['mediumpurple_24',['mediumpurple',['../namespacejuce_1_1Colours.html#a636160abb4ec4502958cd6003991e135',1,'juce::Colours']]],
+  ['mediumseagreen_25',['mediumseagreen',['../namespacejuce_1_1Colours.html#a2a690da01cd85376d6b3aa6796000001',1,'juce::Colours']]],
+  ['mediumslateblue_26',['mediumslateblue',['../namespacejuce_1_1Colours.html#abd71c7a97abd25fa91ab8aab8133a375',1,'juce::Colours']]],
+  ['mediumspringgreen_27',['mediumspringgreen',['../namespacejuce_1_1Colours.html#aec9cc874a8ee7e6ca4f0c25ff86b3428',1,'juce::Colours']]],
+  ['mediumturquoise_28',['mediumturquoise',['../namespacejuce_1_1Colours.html#a899fa84c603b5683560e1c2096f0faf7',1,'juce::Colours']]],
+  ['mediumvioletred_29',['mediumvioletred',['../namespacejuce_1_1Colours.html#a3256b76681325d268127ff21a94d4f87',1,'juce::Colours']]],
   ['message_30',['message',['../classMidiMessageSequence_1_1MidiEventHolder.html#a4d9cf307bd15a6abb4e98cfe03f8f580',1,'MidiMessageSequence::MidiEventHolder::message'],['../classOnlineUnlockForm.html#a0e618e93104800988c1fab673b4836d8',1,'OnlineUnlockForm::message']]],
   ['messagebox_31',['messageBox',['../classStandalonePluginHolder.html#afded677ec9c9ac8a272183a53df49450',1,'StandalonePluginHolder']]],
   ['messages_32',['messages',['../structUnitTestRunner_1_1TestResult.html#ae94f7a271e7f4a5725939036156595bb',1,'UnitTestRunner::TestResult']]],
   ['metadatavalues_33',['metadataValues',['../classAudioFormatReader.html#a8dfe48ed0e171928185c716811f5ecdb',1,'AudioFormatReader']]],
   ['midichannel_34',['midiChannel',['../structMPENote.html#a642fb34a5721d3eb5d3cf84e92706164',1,'MPENote']]],
   ['mididatabase64_35',['midiDataBase64',['../classCoreAudioFormat.html#a6a78852cc234c7fc83ab18c92662feb6',1,'CoreAudioFormat']]],
-  ['midnightblue_36',['midnightblue',['../namespaceColours.html#a8be337df99d6f047de9252e9fa4260f9',1,'Colours']]],
+  ['midnightblue_36',['midnightblue',['../namespacejuce_1_1Colours.html#a6c054173042cb6fbc1500241f674d94c',1,'juce::Colours']]],
   ['millisecondsbeforesaving_37',['millisecondsBeforeSaving',['../structPropertiesFile_1_1Options.html#a35be64ba2da1b72b6b8b599e8ddb0924',1,'PropertiesFile::Options']]],
   ['millisecssincekeypressed_38',['millisecsSinceKeyPressed',['../structApplicationCommandTarget_1_1InvocationInfo.html#a0c1817f71536452a5d69a8e28ecc8534',1,'ApplicationCommandTarget::InvocationInfo']]],
   ['min_39',['min',['../structAccessibilityValueInterface_1_1AccessibleValueRange_1_1MinAndMax.html#a8e1b1d72b8ce4dbcf13123f7fc8abc3b',1,'AccessibilityValueInterface::AccessibleValueRange::MinAndMax']]],
-  ['minheight_40',['minHeight',['../classFlexItem.html#ae2ea8deb9f2f112b791c03e80bfdfd63',1,'FlexItem::minHeight'],['../classGridItem.html#a198556dd7a242251f1a0ef4c162d66d7',1,'GridItem::minHeight']]],
+  ['minheight_40',['minheight',['../classFlexItem.html#ae2ea8deb9f2f112b791c03e80bfdfd63',1,'FlexItem::minHeight'],['../classGridItem.html#a198556dd7a242251f1a0ef4c162d66d7',1,'GridItem::minHeight']]],
   ['minimumseconds_41',['minimumSeconds',['../structPerformanceCounter_1_1Statistics.html#a63ac69c1fee92ba8d3cf31f34aec53da',1,'PerformanceCounter::Statistics']]],
-  ['mintcream_42',['mintcream',['../namespaceColours.html#a771c9f4874a22979990bb4616adbc468',1,'Colours']]],
-  ['minwidth_43',['minWidth',['../classGridItem.html#a0eb1c62d876b6c7099b36d880627b636',1,'GridItem::minWidth'],['../classFlexItem.html#ac4c4db40e054ed849f115a4b4ec89b1e',1,'FlexItem::minWidth']]],
-  ['mistyrose_44',['mistyrose',['../namespaceColours.html#ac12b8560ba87d78473471eff69d7148f',1,'Colours']]],
-  ['moccasin_45',['moccasin',['../namespaceColours.html#a230f2db20e56fc3bbc7e60d49fdc8dec',1,'Colours']]],
+  ['mintcream_42',['mintcream',['../namespacejuce_1_1Colours.html#abe48df03b9a82231706b256786fa9a2d',1,'juce::Colours']]],
+  ['minwidth_43',['minwidth',['../classGridItem.html#a0eb1c62d876b6c7099b36d880627b636',1,'GridItem::minWidth'],['../classFlexItem.html#ac4c4db40e054ed849f115a4b4ec89b1e',1,'FlexItem::minWidth']]],
+  ['mistyrose_44',['mistyrose',['../namespacejuce_1_1Colours.html#ae565dee5c6f1240c9ee1bd3968c3b437',1,'juce::Colours']]],
+  ['moccasin_45',['moccasin',['../namespacejuce_1_1Colours.html#aad619e5504cf614ecbedd312a1a49b0a',1,'juce::Colours']]],
   ['modificationtime_46',['modificationTime',['../structDirectoryContentsList_1_1FileInfo.html#a35f194ff92e35671d7616d1d9e1524b7',1,'DirectoryContentsList::FileInfo']]],
   ['mods_47',['mods',['../group__juce__audio__plugin__client-Unity.html#gaa58b301e5a3a8001feb356b3fea37ce8',1,'mods:&#160;juce_UnityPluginInterface.h'],['../classMouseEvent.html#aaabc365b704e243b193b41113d4e50de',1,'MouseEvent::mods']]],
   ['mousedownposition_48',['mouseDownPosition',['../classMouseEvent.html#af1ecebbf07c64ba115ebbe116df6635a',1,'MouseEvent']]],
